****************
SteemNodeRPC
****************

This class allows to call API methods exposed by the witness node via
websockets.

Defintion
=========
.. autoclass:: beemapi.steemnoderpc.SteemNodeRPC
    :members: rpcexec, __getattr__
